# Juandice

A simple python package that turns all printed text yellow

## Why

To give your scripts juandice, of course

## Requirements

Python, rich, pip

## Okay

Okay

## Changelog

### 0.1.1

Used more reliable method to replace print function

### 0.1.0

Initial release
